% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% Created: 08/20/2012
% Last Modified: 01/31/2015
% Written by: Shivendra Tewari
% e-mail: TewariSG@gmail.com
% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
clear all; close all;
addpath([pwd '\Age_Data'])
addpath([pwd '\Subroutines'])
%% These global variables are for passing between the main and dXdT routines
global KdBP_2 BPT_2 BPT_1 KdBP_1; global X_CU K_sMg X_RTC KCa_RTC
global Cae_add t_add; global MV_Fact
MV_Fact = 1e-6;              % 1 mg protein = 1e-6 Liter mito protien
% Parameters estimated from Age et al 2013
BPT_1 = 1.1629e-01; KdBP_1 = 1.4200e+00; BPT_2 = 1.3826e+00; KdBP_2 = 1.0319e+00;
X_RTC = 1e-6*2.5019e-03; KCa_RTC = 1.3045e+00; X_CU = 25*2.8815e-01; K_sMg = 5.3207e-01;

t_add = 121; t_end = 231; % time of Ca2+ addition and end time for experiments

%% Data files
Cax_Mg00 = load('Matrix_CaDynamics_Mg0p0.txt'); Cax_Mg0125 = load('Matrix_CaDynamics_Mg0p125.txt');
Cax_Mg025 = load('Matrix_CaDynamics_Mg0p25.txt'); Cax_Mg05 = load('Matrix_CaDynamics_Mg0p5.txt');
Cax_Mg10 = load('Matrix_CaDynamics_Mg1p0.txt'); Cax_Mg20 = load('Matrix_CaDynamics_Mg2p0.txt');

datax00 = Cax_Mg00(1:231,:); datax0125 = Cax_Mg0125(1:231,:);
datax025 = Cax_Mg025(1:231,:);  datax05 = Cax_Mg05(1:231,:); 
datax10 = Cax_Mg10(1:231,:); datax20 = Cax_Mg20(1:231,:); 

% datax00 corresponds to experiments done using 0 mM Mg2+. Change datax
% together with Mg2+ concentration for a particular data simulation.
% Cheatsheet (mM): Mg0125 = 0.125 Mg; Mg025 = 0.25 Mg; Mg05 = 0.5 Mg;
% Mg10 = 1.0 Mg; Mg20 = 2.0 Mg;
datax = {datax00}; 
Mgtot_add = 0.0e-3;        % Added MgCl2  (in Molar)

%% Getting Initial Conditions
Ca_add = [0 0.25 0.4 0.5 0.6]*1e-3; % Ca2+ added at time t = 120 sec; units: Molar
mCa_free = [75e-9 70e-9 70e-9 70e-9 70e-9]; % Matrix Calcium in Molar. Note: Under different experimental conditions resting matrix calcium is different adjust these to get perfect fits

for ii = 1:length(Mgtot_add)
    % Fixed metabolite pools in the matrix for mass conservation
    ANtot = 10e-3;             % total adenonucleotides, ATP+ADP, molar
    NADtot = 3e-3;             % total NAD+NADH, molar
    Ctot = 2.7e-3;             % total CytC, Cred+Cox, molar
    Qtot = 1.35e-3;            % total Ubiquinol, UQ+UQH2, molar
    % Experimental buffer conditions for calculating free cation concentrations (initial)
    pH_exp0 = 7.15;            % external pH
    pHx = 7.35; % matrix pH
    H_exp0 = 10^-pH_exp0;      % external [H+], M
    Ktot_exp0 = 130e-3;        % external total [K+], M
    Mgtot_exp0 = Mgtot_add(ii);    % external total [Mg2+], M
    Catot_exp0 = 6e-9;         % external total [Ca2+], M
    Natot_exp0 = 0e-3;         % external total [Na+], M
    ATP_exp0 = 0e-3;           % external [ATP], M
    ADP_exp0 = 0e-3;           % external [ADP], M
    Pi_exp0 = 5e-3;            % external [Pi], M
    EGTA_exp0 = 1e-3;          % external [EGTA], M
    Lig_exp0 = 0e-3;           % external [ligand], M

    % Calculate buffer free cations based on total buffer cations and reactants (initial)
    Cation_tot = [Ktot_exp0, Mgtot_exp0, Catot_exp0, Natot_exp0];
    React_tot = [ATP_exp0, ADP_exp0, Pi_exp0, EGTA_exp0, Lig_exp0];
    Cation_free_0 = 0*Cation_tot;
    options_opt = optimset('Display','off','TolFun',1e-15);
    [Cation_free] = fsolve(@get_cation_balance_eqs,Cation_free_0,options_opt,Cation_tot,React_tot,pH_exp0);
    K_exp0 = Cation_free(1);   % external free [K+], M
    Mg_exp0 = Cation_free(2);  % external free [Mg2+], M
    Ca_exp0 = Cation_free(3);  % external free [Ca2+], M
    Na_exp0 = Cation_free(4);  % external free [Na+], M

    % Initial conditions for the integrated model of OxPhos and cation handling
    dPsi0 = 195; NADH_x0 = 8*NADtot/10; QH20 = 1*Qtot/10; Cred0 = 1*Ctot/10;
    ATP_x0 = 9*ANtot/10; ADP_x0 = ANtot-ATP_x0; Pi_x0 = Pi_exp0; H_x0 = 10^(-pHx);
    K_x0 = K_exp0; Mg_x0 = 0.5e-3; Ca_x0 = 60e-9; Na_x0 = Na_exp0; ATP_i0 = ATP_exp0;
    ADP_i0 = ADP_exp0; Pi_i0 = Pi_exp0; ATP_e0 = ATP_exp0; ADP_e0 = ADP_exp0;
    Pi_e0 = Pi_exp0; H_e0 = H_exp0; K_e0 = K_exp0; Mg_e0 = Mg_exp0; Ca_e0 = Ca_exp0;
    Na_e0 = Na_exp0; CaHPO4s_x0 = 0e-6; Ca3PO42s_x0 = 0e-6; RO_0 = 1;
    [CaSBP1_e0,~] = CaeBuffering_Equilb(Ca_e0,Mg_e0,H_e0);

    x0(1,1) = dPsi0; x0(2,1) = NADH_x0; x0(3,1) = QH20; x0(4,1) = Cred0; x0(5,1) = ATP_x0;
    x0(6,1) = ADP_x0; x0(7,1) = Pi_x0; x0(8,1) = H_x0; x0(9,1) = K_x0; x0(10,1) = Mg_x0;
    x0(11,1) = Ca_x0; x0(12,1) = Na_x0; x0(13,1) = ATP_i0; x0(14,1) = ADP_i0;
    x0(15,1) = Pi_i0; x0(16,1) = ATP_e0; x0(17,1) = ADP_e0; x0(18,1) = Pi_e0;
    x0(19,1) = H_e0; x0(20,1) = K_e0; x0(21,1) = Mg_e0; x0(22,1) = Ca_e0; x0(23,1) = Na_e0;
%     x0(24,1) = CaHPO4s_x0; x0(25,1) = Ca3PO42s_x0; x0(26,1) = RO_0; 
    x0(24,1) = CaSBP1_e0; x0(25,1) = 0.9; x0(26,1) = 0.0; x0(27,1) = 0.0;
    options = []; Cae_add = 0;
    [~, xin] = ode15s(@IsoMito_dXdT,[-10 0],x0,options);
for jj = 1:size(Ca_add,2)
%%
    x0 = xin(end,:);
    x0(11) = mCa_free(ii,jj);
    Cae_add = Ca_add(ii,jj);
    options = odeset('BDF','on','MaxOrder',5,'RelTol',1e-6,'MaxStep',5e-2);%    
    [t{jj} x{jj}] = ode15s(@IsoMito_dXdT,[0:t_end],x0,options);
    dPsi{jj} = x{jj}(:,1); NADH_x{jj} = x{jj}(:,2); QH2{jj} = x{jj}(:,3);
    Pi_e{jj} = x{jj}(:,18); Mg_e{jj} = x{jj}(:,21); Ca_e{jj} = x{jj}(:,22); 
    Ca_x{jj} = x{jj}(:,11); Pi_x{jj} = x{jj}(:,7); Mg_x{jj} = x{jj}(:,10); 
    Pc1{jj} = x{jj}(:,25); Po1{jj} = x{jj}(:,26);     Po2{jj} = x{jj}(:,27);
end
    index = 1:5:231;
    Caxdata = datax{ii};
    figure(10); clf; set(figure(10),'Units','inches','Position',[0.5 0.5 6 4]);
    subplot(1,1,ii);
    errorbar(Caxdata(index,1), Caxdata(index,2).*1e3,0.5*Caxdata(index,3).*1e3,'bo','linewidth',1.5,'MarkerEdgeColor','b',...
        'MarkerFaceColor','b','Markersize',4); hold on;
    errorbar(Caxdata(index,1), Caxdata(index,4).*1e3,0.5*Caxdata(index,5).*1e3,'go','linewidth',1.5,'MarkerEdgeColor','g',...
        'MarkerFaceColor','g','Markersize',4); hold on;
    errorbar(Caxdata(index,1), Caxdata(index,6).*1e3,0.5*Caxdata(index,7).*1e3,'ro','linewidth',1.5,'MarkerEdgeColor','r',...
        'MarkerFaceColor','r','Markersize',4); hold on;
    errorbar(Caxdata(index,1), Caxdata(index,8).*1e3,0.5*Caxdata(index,9).*1e3,'co','linewidth',1.5,'MarkerEdgeColor','c',...
        'MarkerFaceColor','c','Markersize',4); hold on;
    errorbar(Caxdata(index,1), Caxdata(index,10).*1e3,0.5*Caxdata(index,11).*1e3,'mo','linewidth',1.5,'MarkerEdgeColor','m',...
        'MarkerFaceColor','m','Markersize',4); hold on;
    axis([60 240 0 1500]); set(gca,'XTick',(60:60:240)); set(gca,'YTick',(0:300:1500));
    ylabel('Matrix free [Ca^{2+}] (nM)'); xlabel('Time (s)');grid on;hold on;

    ls = {'b','g','r','c','m','k'};

    for j = 1:size(Ca_add,2)
        plot(t{j},Ca_x{j}.*1e+9,ls{j}, 'LineWidth',2.0);set(gca, 'LineWidth',2.0,'FontSize',14);
    end

end