function [J_CaEGTA] = CaeBuffering_Model(Ca,CaEGTA,Mg,H)

% Calculation of Kapp_CaEGTA at given pH and Mg2+
pH = -log10(H);       % pH of the medium
pK_HEGTA  = 9.58;     % HEGTA(3-)  = H(+) + EGTA(4-)
pK_H2EGTA = 8.96;     % H2EGTA(2-) = H(+) + HEGTA(3-)
pK_MgEGTA = 5.21;     % MgEGTA(2-) = Mg(2+) + EGTA(4-)
pK_CaEGTA = 10.97;    % CaEGTA(2-) = Ca(2+) + EGTA(4-)
P_HMgEGTA = 1 + 10^(-pH+pK_HEGTA) + 10^(-2*pH+pK_HEGTA+pK_H2EGTA) + Mg*10^(pK_MgEGTA);
Kapp_CaEGTA = 10^(-pK_CaEGTA)*P_HMgEGTA;

% Parameters and mass-action flux for Ca2+ binding to EGTA
kf_CaEGTA = 1.5e+6;   % kf for Ca + EGTA <==> CaEGTA reaction
kb_CaEGTA = Kapp_CaEGTA*kf_CaEGTA; % kb for Ca + EGTA <==> CaEGTA reaction (kb_CaEGTA = 0.3 at pH = 7.15)
EGTAtot = 1.0e-3;     % Total EGTA concentration
EGTA = EGTAtot - CaEGTA;  % Free EGTA concentration
J_CaEGTA = kf_CaEGTA*Ca*EGTA - kb_CaEGTA*CaEGTA;
