function [Eqs] = get_cation_balance_eqs(Cation_free,Cation_tot,React_tot,pH)

% Call to get binding fractions of reactants with cations, given pH and free cations
[~,React_frac,~] = get_binding_poly_frac(React_tot,Cation_free,pH);

ATP_frac = React_frac(1,:);  ADP_frac  = React_frac(2,:);  
Pi_frac  = React_frac(3,:);  EGTA_frac = React_frac(4,:); 
Lig_frac = React_frac(5,:);  
 
ATP_free = ATP_frac(1); HATP = ATP_frac(2); H2ATP = ATP_frac(3); 
KATP = ATP_frac(4); MgATP = ATP_frac(5); MgHATP = ATP_frac(6); 
Mg2ATP = ATP_frac(7); CaATP = ATP_frac(8); CaHATP = ATP_frac(9); 
NaATP = ATP_frac(10); 

ADP_free = ADP_frac(1); HADP = ADP_frac(2); H2ADP = ADP_frac(3); 
KADP = ADP_frac(4); MgADP = ADP_frac(5); MgHADP = ADP_frac(6); 
Mg2ADP = ADP_frac(7); CaADP = ADP_frac(8); CaHADP = ADP_frac(9); 
NaADP = ADP_frac(10);
 
HPO4 = Pi_frac(1); H2PO4 = Pi_frac(2); KHPO4 = Pi_frac(3); 
KH2PO4 = Pi_frac(4); K2HPO4 = Pi_frac(5); MgHPO4 = Pi_frac(6); 
MgH2PO4 = Pi_frac(7); CaHPO4 = Pi_frac(8); CaH2PO4 = Pi_frac(9);
NaHPO4 = Pi_frac(10);

EGTA_free = EGTA_frac(1); HEGTA = EGTA_frac(2); H2EGTA  = EGTA_frac(3); 
KEGTA = EGTA_frac(4); MgEGTA = EGTA_frac(5); MgHEGTA = EGTA_frac(6); 
CaEGTA = EGTA_frac(7); CaHEGTA = EGTA_frac(8); NaEGTA = EGTA_frac(9);

Lig_free = Lig_frac(1); HLig = Lig_frac(2); KLig = Lig_frac(3);
MgLig = Lig_frac(4); CaLig = Lig_frac(5); NaLig = Lig_frac(6);

% Set the system of equations to be solved for free cation concentrations
K_free = Cation_free(1); Mg_free = Cation_free(2); 
Ca_free = Cation_free(3); Na_free = Cation_free(4);

K_tot = Cation_tot(1); Mg_tot = Cation_tot(2); 
Ca_tot = Cation_tot(3); Na_tot = Cation_tot(4); 

Eqs(1) = K_tot - K_free - (KATP+KADP) - (KHPO4+KH2PO4+2*K2HPO4) - KEGTA - KLig;
Eqs(2) = Mg_tot - Mg_free - (MgATP+MgHATP+2*Mg2ATP) - (MgADP+MgHADP+2*Mg2ADP)...
       - (MgHPO4+MgH2PO4) - (MgEGTA+MgHEGTA) - MgLig;
Eqs(3) = Ca_tot - Ca_free - (CaATP+CaHATP) - (CaADP+CaHADP) - (CaHPO4+CaH2PO4) ...
       - (CaEGTA+CaHEGTA) - CaLig;
Eqs(4) = Na_tot - Na_free - NaATP - NaADP - NaHPO4 - NaEGTA - NaLig; 
    