function [dy, J_RyR] = KeizerLevine(t,y,Mge)
global Ca_add
dy = zeros(5,1);
Cax = y(1);
Cae = y(2);
Pc1 = y(3);
Po1 = y(4);
Po2 = y(5);

t_add = 10;
dt_add = 0.05;
dPsi = 190e-3;
P = Pc1 + Po1 + Po2;
Pc2 = 1 - P;
K_M = 200e-6; n_M = 1.1;
f_Mg = 1./(1 + (Mge/K_M).^n_M);

% Thermodynamics constants
Z_Ca = 2;        % Valency of Ca(uniteless)
F = 96484.6;     % Faraday's constant(J*V^-1*mol^-1)(Coul*mol^-1)
R = 8.314;       % Universal gas constant(J*mol^-1*K^-1)
T = 298;         % Temperature(K)
FRT = F/(R*T);   % V^-1 
dPhi = Z_Ca*dPsi*FRT; % Nondimensional RaM_parameter

%% RyR Flux 
k_a = 28.8; k_b = 1*385.9; k_c = 1*0.1;% s^-1
ka = 1500; % uM^-4 s^-1
kb = 1500; % uM^-3 s^-1
kc = (1/f_Mg)*1.75; % s^-1
gRyR = 80*0; % s^-1
KCa_RyR = 7; % uM
c1 = 0.185;


Jcyt = 0*Ca_add*(1/(dt_add*sqrt(2*pi)))*exp(-(t-t_add)^2/(2*dt_add^2));

num = gRyR*(Po1 + Po2).*(exp(dPhi/2)*Cae/KCa_RyR - exp(-dPhi/2)*Cax/KCa_RyR); % umol per second per mg mito protein
den = 1 + Cae/KCa_RyR + Cax/KCa_RyR;

J_RyR = num./den;

dy(1) = +J_RyR/c1;
dy(2) = Jcyt - c1*J_RyR; 
dy(3) = -ka*(Cae.^4).*Pc1 + k_a*Po1;
dy(4) = ka*(Cae.^4).*Pc1 - k_a*Po1 - kb*(Cae.^3).*Po1 + k_b*Po2 - kc*Po1 + k_c*Pc2;
dy(5) = kb*(Cae.^3).*Po1 - k_b*Po2;
end